@@ -1,9 +1,11 @@
 #![deny(
     clippy::all,
     missing_debug_implementations,
-    missing_copy_implementations
+    missing_copy_implementations,
+    missing_docs,
+    clippy::cargo
 )]
-#![warn(clippy::pedantic, missing_docs)]
+#![warn(clippy::pedantic)]
 #![allow(clippy::missing_errors_doc)]
 
 //! A Monzo client in pure rust.
@@ -43,6 +45,9 @@
 //! }
 //! ```
 
+#[cfg(doctest)]
+doc_comment::doctest!("../README.md");
+
 mod client;
 #[doc(inline)]
 pub use client::Client;
